@@ -1,7 +1,9 @@
+# frozen_string_literal: true
+
 module MIME
   class Types
     module Data
-      VERSION = '3.2015.1120'
+      VERSION = "3.2023.0808"
 
       # The path that will be used for loading the MIME::Types data. The
       # default location is __FILE__/../../../../data, which is where the data
@@ -13,7 +15,7 @@ module MIME
       # System maintainer note: this is the constant to change when packaging
       # mime-types for your system. It is recommended that the path be
       # something like /usr/share/ruby/mime-types/.
-      PATH = File.expand_path('../../../../data', __FILE__)
+      PATH = File.expand_path("../../../../data", __FILE__)
     end
   end
 end
